@@ -44,7 +44,8 @@ public:
   Lum::Model::Boolean* GetShowAll();
 
   void CalcSize();
-  void Draw(int x, int y, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
 
