@@ -33,6 +33,8 @@
 #include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Manager/FileSystem.h>
+
 #include <Lum/Images/Loader/JPEG.h>
 
 static size_t WriteFunction(void* ptr, size_t size, size_t nmemb, void* stream)
@@ -128,10 +130,17 @@ void DownloadImageTask::Run()
     return;
   }
 
+  std::wstring    tmpDir;
   Lum::Base::Path path;
   FILE            *tmpfile;
 
-  path.SetNativeDir(Lum::Base::Path::GetTemporary());
+  if (!Lum::Manager::FileSystem::Instance()->GetEntry(Lum::Manager::FileSystem::userTmpDir,
+                                                     tmpDir)) {
+    error="Cannot get temporary directory";
+    return;
+  }
+
+  path.SetNativeDir(tmpDir);
   path.SetBaseName(L"WhoAmI-tmp.jpg");
 
   tmpfile=fopen(Lum::Base::WStringToString(path.GetPath()).c_str(),"w+b");
